import React, { useState, useEffect } from "react";
import logo from "../assets/logo.png";
import { useNavigate } from "react-router-dom";
import "./Header.css";
import Movie from "./Movie";
import { Outlet } from "react-router-dom";
const Header = () => {
  const [searchTerm, setSearchTerm] = useState("");
  const [suggestions, setSuggestions] = useState([]);
  const [genre, setGenre] = useState("");
  const [year, setYear] = useState(""); 
  const [rating, setRating] = useState([0, 10]); 
  const navigate = useNavigate();

  useEffect(() => {
    if (searchTerm) {
      const fetchSuggestions = async () => {
        const response = await fetch(
          `https://api.themoviedb.org/3/search/movie?api_key=59690efd14e375225c4531fcdced2901&query=${searchTerm}`
        );
        const data = await response?.json();
        setSuggestions(data?.results);
      };
      fetchSuggestions();
    } else {
      setSuggestions([]);
    }
  }, [searchTerm]);

  const handleSearchChange = (e) => {
    setSearchTerm(e.target.value);
  };

  const handleSuggestionClick = (id) => {
    navigate(`/search?id=${id}`);
    setSearchTerm("");
    setSuggestions([]);
  };

  return (
    <>
        <header >
          <div className="header-container">
            <div>
              <img src={logo} alt="logo" />
            </div>
            <div className="filters">
              <select
                value={genre}
                onChange={(e) => setGenre(e.target.value)}
              >
                <option value="">Select Genre</option>
                <option value="28">Action</option>
                <option value="35">Comedy</option>
                <option value="18">Drama</option>
              </select>

              <select
                value={year}
                onChange={(e) => setYear(e.target.value)}
              >
                <option value="">Select Year</option>
                <option value="2024">2024</option>
                <option value="2023">2023</option>
                <option value="2022">2022</option>
              </select>

             {rating.map((value, index) => (
            <input
             key={index}
             type="range"
              min="0"
              max="10"
              step="0.1"
              value={value}
           onChange={(e) => {
            const newRating = [...rating]; 
            newRating[index] = parseFloat(e.target.value); 
           setRating(newRating); 
           }}
  />
))}

              <span>
                {rating[0]} - {rating[1]}
              </span>
            </div>

            <div className="search-container">
              <input
                type="text"
                value={searchTerm}
                onChange={handleSearchChange}
                placeholder="Search for movies..."
              />
              {suggestions?.length > 0 && (
                <ul >
                  {suggestions.map((movie) => (
                    <li
                      key={movie?.id}
                      onClick={() => handleSuggestionClick(movie?.id)}
                    >
                      {movie?.title}
                    </li>
                  ))}
                </ul>
              )}
            </div>
          </div>
        </header>
<Outlet/>
        <Movie filters={{ genre, year, rating }} />
    </>
  );
};

export default Header;
